# Class: Bond

A Network bond that combines physical network interfaces, also known as link aggregation

## Fields for class: Bond

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`auto_update_mac`   |`bool`              |_RO/runtime_   |true if the MAC was taken from the primary slave when the bond was created, and false if the client specified the MAC|
|`links_up`          |`int`               |_RO/runtime_   |Number of links up in this bond         |
|`master`            |`PIF ref`           |_RO/constructor_|The bonded interface                    |
|`mode`              |`bond_mode`         |_RO/runtime_   |The algorithm used to distribute traffic among the bonded NICs|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`primary_slave`     |`PIF ref`           |_RO/runtime_   |The PIF of which the IP configuration and MAC were copied to the bond, and which will receive all configuration/VLANs/VIFs on the bond if the bond is destroyed|
|`properties`        |`(string -> string) map`|_RO/runtime_   |Additional configuration properties specific to the bond mode.|
|`slaves`            |`PIF ref set`       |_RO/runtime_   |The interfaces which are part of this bond|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: Bond

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given Bond.

_Signature:_

```
void add_to_other_config (session ref session_ref, Bond ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create an interface bond

_Signature:_

```
Bond ref create (session ref session_ref, network ref network, PIF ref set members, string MAC, bond_mode mode, (string -> string) map properties)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`network ref`                 |`network`                     |Network to add the bonded PIF to        |
|`PIF ref set`                 |`members`                     |PIFs to add to this bond                |
|`string`                      |`MAC`                         |The MAC address to use on the bond itself. If this parameter is the empty string then the bond will inherit its MAC address from the primary slave.|
|`bond_mode`                   |`mode`                        |Bonding mode to use for the new bond    |
|`(string -> string) map`      |`properties`                  |Additional configuration parameters specific to the bond mode|

_Minimum Role:_ pool-operator

_Return Type:_ `Bond ref`

The reference of the created Bond object

### RPC name: destroy

_Overview:_

Destroy an interface bond

_Signature:_

```
void destroy (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |Bond to destroy                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the Bonds known to the system.

_Signature:_

```
Bond ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Bond references to Bond records for all Bonds known to the system.

_Signature:_

```
(Bond ref -> Bond record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(Bond ref -> Bond record) map`

records of all objects

### RPC name: get&#95;auto&#95;update&#95;mac

_Overview:_

Get the auto&#95;update&#95;mac field of the given Bond.

_Signature:_

```
bool get_auto_update_mac (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Bond instance with the specified UUID.

_Signature:_

```
Bond ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref`

reference to the object

### RPC name: get&#95;links&#95;up

_Overview:_

Get the links&#95;up field of the given Bond.

_Signature:_

```
int get_links_up (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;master

_Overview:_

Get the master field of the given Bond.

_Signature:_

```
PIF ref get_master (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;mode

_Overview:_

Get the mode field of the given Bond.

_Signature:_

```
bond_mode get_mode (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bond_mode`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given Bond.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;primary&#95;slave

_Overview:_

Get the primary&#95;slave field of the given Bond.

_Signature:_

```
PIF ref get_primary_slave (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

### RPC name: get&#95;properties

_Overview:_

Get the properties field of the given Bond.

_Signature:_

```
(string -> string) map get_properties (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Bond.

_Signature:_

```
Bond record get_record (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Bond record`

all fields from the object

### RPC name: get&#95;slaves

_Overview:_

Get the slaves field of the given Bond.

_Signature:_

```
PIF ref set get_slaves (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Bond.

_Signature:_

```
string get_uuid (session ref session_ref, Bond ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given Bond.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, Bond ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;mode

_Overview:_

Change the bond mode

_Signature:_

```
void set_mode (session ref session_ref, Bond ref self, bond_mode value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |The bond                                |
|`bond_mode`                   |`value`                       |The new bond mode                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given Bond.

_Signature:_

```
void set_other_config (session ref session_ref, Bond ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;property

_Overview:_

Set the value of a property of the bond

_Signature:_

```
void set_property (session ref session_ref, Bond ref self, string name, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`Bond ref`                    |`self`                        |The bond                                |
|`string`                      |`name`                        |The property name                       |
|`string`                      |`value`                       |The property value                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
