# Class: message

An message for the attention of the administrator

## Fields for class: message

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`body`              |`string`            |_RO/runtime_   |The body of the message                 |
|`cls`               |`cls`               |_RO/runtime_   |The class of the object this message is associated with|
|`name`              |`string`            |_RO/runtime_   |The name of the message                 |
|`obj_uuid`          |`string`            |_RO/runtime_   |The uuid of the object this message is associated with|
|`priority`          |`int`               |_RO/runtime_   |The message priority, 0 being low priority|
|`timestamp`         |`datetime`          |_RO/runtime_   |The time at which the message was created|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: message

### RPC name: create

_Overview:_

_Signature:_

```
message ref create (session ref session_ref, string name, int priority, cls cls, string obj_uuid, string body)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name`                        |The name of the message                 |
|`int`                         |`priority`                    |The priority of the message             |
|`cls`                         |`cls`                         |The class of object this message is associated with|
|`string`                      |`obj_uuid`                    |The uuid of the object this message is associated with|
|`string`                      |`body`                        |The body of the message                 |

_Minimum Role:_ pool-operator

_Return Type:_ `message ref`

The reference of the created message

### RPC name: destroy

_Overview:_

_Signature:_

```
void destroy (session ref session_ref, message ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`message ref`                 |`self`                        |The reference of the message to destroy |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: destroy&#95;many

_Overview:_

_Signature:_

```
void destroy_many (session ref session_ref, message ref set messages)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`message ref set`             |`messages`                    |Messages to destroy                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get

_Overview:_

_Signature:_

```
(message ref -> message record) map get (session ref session_ref, cls cls, string obj_uuid, datetime since)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`cls`                         |`cls`                         |The class of object                     |
|`string`                      |`obj_uuid`                    |The uuid of the object                  |
|`datetime`                    |`since`                       |The cutoff time                         |

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The relevant messages

### RPC name: get&#95;all

_Overview:_

_Signature:_

```
message ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `message ref set`

The references to the messages

### RPC name: get&#95;all&#95;records

_Overview:_

_Signature:_

```
(message ref -> message record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The messages

### RPC name: get&#95;all&#95;records&#95;where

_Overview:_

_Signature:_

```
(message ref -> message record) map get_all_records_where (session ref session_ref, string expr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`expr`                        |The expression to match &#40;not currently used&#41;|

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The messages

### RPC name: get&#95;by&#95;uuid

_Overview:_

_Signature:_

```
message ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |The uuid of the message                 |

_Minimum Role:_ read-only

_Return Type:_ `message ref`

The message reference

### RPC name: get&#95;record

_Overview:_

_Signature:_

```
message record get_record (session ref session_ref, message ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`message ref`                 |`self`                        |The reference to the message            |

_Minimum Role:_ read-only

_Return Type:_ `message record`

The message record

### RPC name: get&#95;since

_Overview:_

_Signature:_

```
(message ref -> message record) map get_since (session ref session_ref, datetime since)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`datetime`                    |`since`                       |The cutoff time                         |

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The relevant messages
