# Class: PBD

The physical block devices through which hosts access SRs

## Fields for class: PBD

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`currently_attached`|`bool`              |_RO/runtime_   |is the SR currently attached on this host?|
|`device_config`     |`(string -> string) map`|_RO/constructor_|a config string to string map that is provided to the host's SR&#45;backend&#45;driver|
|`host`              |`host ref`          |_RO/constructor_|physical machine on which the pbd is available|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`SR`                |`SR ref`            |_RO/constructor_|the storage repository that the pbd realises|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: PBD

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PBD.

_Signature:_

```
void add_to_other_config (session ref session_ref, PBD ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new PBD instance, and return its handle.

_Signature:_

```
PBD ref create (session ref session_ref, PBD record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD record`                  |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `PBD ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified PBD instance.

_Signature:_

```
void destroy (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PBDs known to the system.

_Signature:_

```
PBD ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PBD references to PBD records for all PBDs known to the system.

_Signature:_

```
(PBD ref -> PBD record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PBD ref -> PBD record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PBD instance with the specified UUID.

_Signature:_

```
PBD ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref`

reference to the object

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given PBD.

_Signature:_

```
bool get_currently_attached (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;device&#95;config

_Overview:_

Get the device&#95;config field of the given PBD.

_Signature:_

```
(string -> string) map get_device_config (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;host

_Overview:_

Get the host field of the given PBD.

_Signature:_

```
host ref get_host (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PBD.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PBD.

_Signature:_

```
PBD record get_record (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PBD record`

all fields from the object

### RPC name: get&#95;SR

_Overview:_

Get the SR field of the given PBD.

_Signature:_

```
SR ref get_SR (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PBD.

_Signature:_

```
string get_uuid (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: plug

_Overview:_

Activate the specified PBD, causing the referenced SR to be attached and scanned

_Signature:_

```
void plug (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |The PBD to activate                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `SR_UNKNOWN_DRIVER`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PBD.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, PBD ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;device&#95;config

_Overview:_

Sets the PBD's device&#95;config field

_Signature:_

```
void set_device_config (session ref session_ref, PBD ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |The PBD to modify                       |
|`(string -> string) map`      |`value`                       |The new value of the PBD's device&#95;config|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PBD.

_Signature:_

```
void set_other_config (session ref session_ref, PBD ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: unplug

_Overview:_

Deactivate the specified PBD, causing the referenced SR to be detached and nolonger scanned

_Signature:_

```
void unplug (session ref session_ref, PBD ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PBD ref`                     |`self`                        |The PBD to deactivate                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
