# Class: session

A session

## Fields for class: session

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`auth_user_name`    |`string`            |_RO/runtime_   |the subject name of the user that was externally authenticated. If a session instance has is&#95;local&#95;superuser set, then the value of this field is undefined.|
|`auth_user_sid`     |`string`            |_RO/runtime_   |the subject identifier of the user that was externally authenticated. If a session instance has is&#95;local&#95;superuser set, then the value of this field is undefined.|
|`client_certificate`|`bool`              |_RO/runtime_   |indicates whether this session was authenticated using a client certificate|
|`is_local_superuser`|`bool`              |_RO/runtime_   |true iff this session was created using local superuser credentials|
|`last_active`       |`datetime`          |_RO/runtime_   |Timestamp for last time session was active|
|`originator`        |`string`            |_RO/runtime_   |a key string provided by a API user to distinguish itself from other users sharing the same login name|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`parent`            |`session ref`       |_RO/constructor_|references the parent session that created this session|
|`pool`              |`bool`              |_RO/runtime_   |True if this session relates to a intra&#45;pool login, false otherwise|
|`rbac_permissions`  |`string set`        |_RO/constructor_|list with all RBAC permissions for this session|
|`subject`           |`subject ref`       |_RO/runtime_   |references the subject instance that created the session. If a session instance has is&#95;local&#95;superuser set, then the value of this field is undefined.|
|`tasks`             |`task ref set`      |_RO/runtime_   |list of tasks created using the current session|
|`this_host`         |`host ref`          |_RO/runtime_   |Currently connected host                |
|`this_user`         |`user ref`          |_RO/runtime_   |Currently connected user                |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`validation_time`   |`datetime`          |_RO/runtime_   |time when session was last validated    |

## RPCs associated with class: session

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given session.

_Signature:_

```
void add_to_other_config (session ref session_ref, session ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: change&#95;password

_Overview:_

Change the account password; if your session is authenticated with root privileges then the old&#95;pwd is validated and the new&#95;pwd is set regardless

_Signature:_

```
void change_password (session ref session_ref, string old_pwd, string new_pwd)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`old_pwd`                     |Old password for account                |
|`string`                      |`new_pwd`                     |New password for account                |

_Return Type:_ `void`

### RPC name: create&#95;from&#95;db&#95;file

_Overview:_

_Signature:_

```
session ref create_from_db_file (session ref session_ref, string filename)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`filename`                    |Database dump filename.                 |

_Return Type:_ `session ref`

ID of newly created session

### RPC name: get&#95;all&#95;subject&#95;identifiers

_Overview:_

Return a list of all the user subject&#45;identifiers of all existing sessions

_Signature:_

```
string set get_all_subject_identifiers (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `string set`

The list of user subject&#45;identifiers of all existing sessions

### RPC name: get&#95;auth&#95;user&#95;name

_Overview:_

Get the auth&#95;user&#95;name field of the given session.

_Signature:_

```
string get_auth_user_name (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;auth&#95;user&#95;sid

_Overview:_

Get the auth&#95;user&#95;sid field of the given session.

_Signature:_

```
string get_auth_user_sid (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the session instance with the specified UUID.

_Signature:_

```
session ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `session ref`

reference to the object

### RPC name: get&#95;client&#95;certificate

_Overview:_

Get the client&#95;certificate field of the given session.

_Signature:_

```
bool get_client_certificate (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;is&#95;local&#95;superuser

_Overview:_

Get the is&#95;local&#95;superuser field of the given session.

_Signature:_

```
bool get_is_local_superuser (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;last&#95;active

_Overview:_

Get the last&#95;active field of the given session.

_Signature:_

```
datetime get_last_active (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;originator

_Overview:_

Get the originator field of the given session.

_Signature:_

```
string get_originator (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given session.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;parent

_Overview:_

Get the parent field of the given session.

_Signature:_

```
session ref get_parent (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `session ref`

value of the field

### RPC name: get&#95;pool

_Overview:_

Get the pool field of the given session.

_Signature:_

```
bool get_pool (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;rbac&#95;permissions

_Overview:_

Get the rbac&#95;permissions field of the given session.

_Signature:_

```
string set get_rbac_permissions (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given session.

_Signature:_

```
session record get_record (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `session record`

all fields from the object

### RPC name: get&#95;subject

_Overview:_

Get the subject field of the given session.

_Signature:_

```
subject ref get_subject (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `subject ref`

value of the field

### RPC name: get&#95;tasks

_Overview:_

Get the tasks field of the given session.

_Signature:_

```
task ref set get_tasks (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

value of the field

### RPC name: get&#95;this&#95;host

_Overview:_

Get the this&#95;host field of the given session.

_Signature:_

```
host ref get_this_host (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

### RPC name: get&#95;this&#95;user

_Overview:_

Get the this&#95;user field of the given session.

_Signature:_

```
user ref get_this_user (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `user ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given session.

_Signature:_

```
string get_uuid (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;validation&#95;time

_Overview:_

Get the validation&#95;time field of the given session.

_Signature:_

```
datetime get_validation_time (session ref session_ref, session ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: local&#95;logout

_Overview:_

Log out of local session.

_Signature:_

```
void local_logout (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: login&#95;with&#95;password

_Overview:_

Attempt to authenticate the user, returning a session reference if successful

_Signature:_

```
session ref login_with_password (string uname, string pwd, string version, string originator)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`string`                      |`uname`                       |Username for login.                     |
|`string`                      |`pwd`                         |Password for login.                     |
|`string`                      |`version`                     |Client API version.                     |
|`string`                      |`originator`                  |Key string for distinguishing different API users sharing the same login name.|

_Minimum Role:_ read-only

_Return Type:_ `session ref`

reference of newly created session

_Possible Error Codes:_ `SESSION_AUTHENTICATION_FAILED`, `HOST_IS_SLAVE`

### RPC name: logout

_Overview:_

Log out of a session

_Signature:_

```
void logout (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `void`

### RPC name: logout&#95;subject&#95;identifier

_Overview:_

Log out all sessions associated to a user subject&#45;identifier, except the session associated with the context calling this function

_Signature:_

```
void logout_subject_identifier (session ref session_ref, string subject_identifier)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`subject_identifier`          |User subject&#45;identifier of the sessions to be destroyed|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given session.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, session ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given session.

_Signature:_

```
void set_other_config (session ref session_ref, session ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`session ref`                 |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: slave&#95;local&#95;login&#95;with&#95;password

_Overview:_

Authenticate locally against a slave in emergency mode. Note the resulting sessions are only good for use on this host.

_Signature:_

```
session ref slave_local_login_with_password (string uname, string pwd)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`string`                      |`uname`                       |Username for login.                     |
|`string`                      |`pwd`                         |Password for login.                     |

_Minimum Role:_ pool-admin

_Return Type:_ `session ref`

ID of newly created session
