# Class: VMSS

VM Snapshot Schedule

## Fields for class: VMSS

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`enabled`           |`bool`              |_RW_           |enable or disable this snapshot schedule|
|`frequency`         |`vmss_frequency`    |_RO/constructor_|frequency of taking snapshot from snapshot schedule|
|`last_run_time`     |`datetime`          |_RO/runtime_   |time of the last snapshot               |
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`retained_snapshots`|`int`               |_RO/constructor_|maximum number of snapshots that should be stored at any time|
|`schedule`          |`(string -> string) map`|_RO/constructor_|schedule of the snapshot containing 'hour', 'min', 'days'. Date/time&#45;related information is in Local Timezone|
|`type`              |`vmss_type`         |_RO/constructor_|type of the snapshot schedule           |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VMs`               |`VM ref set`        |_RO/runtime_   |all VMs attached to this snapshot schedule|

## RPCs associated with class: VMSS

### RPC name: add&#95;to&#95;schedule

_Overview:_

_Signature:_

```
void add_to_schedule (session ref session_ref, VMSS ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The snapshot schedule                   |
|`string`                      |`key`                         |the key to add                          |
|`string`                      |`value`                       |the value to add                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new VMSS instance, and return its handle.

_Signature:_

```
VMSS ref create (session ref session_ref, VMSS record args)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS record`                 |`args`                        |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `VMSS ref`

reference to the newly created object

### RPC name: destroy

_Overview:_

Destroy the specified VMSS instance.

_Signature:_

```
void destroy (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VMSSs known to the system.

_Signature:_

```
VMSS ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VMSS references to VMSS records for all VMSSs known to the system.

_Signature:_

```
(VMSS ref -> VMSS record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VMSS ref -> VMSS record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VMSS instances with the given label.

_Signature:_

```
VMSS ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VMSS instance with the specified UUID.

_Signature:_

```
VMSS ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref`

reference to the object

### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given VMSS.

_Signature:_

```
bool get_enabled (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;frequency

_Overview:_

Get the frequency field of the given VMSS.

_Signature:_

```
vmss_frequency get_frequency (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmss_frequency`

value of the field

### RPC name: get&#95;last&#95;run&#95;time

_Overview:_

Get the last&#95;run&#95;time field of the given VMSS.

_Signature:_

```
datetime get_last_run_time (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VMSS.

_Signature:_

```
string get_name_description (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VMSS.

_Signature:_

```
string get_name_label (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VMSS.

_Signature:_

```
VMSS record get_record (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VMSS record`

all fields from the object

### RPC name: get&#95;retained&#95;snapshots

_Overview:_

Get the retained&#95;snapshots field of the given VMSS.

_Signature:_

```
int get_retained_snapshots (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;schedule

_Overview:_

Get the schedule field of the given VMSS.

_Signature:_

```
(string -> string) map get_schedule (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given VMSS.

_Signature:_

```
vmss_type get_type (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmss_type`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VMSS.

_Signature:_

```
string get_uuid (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VMs

_Overview:_

Get the VMs field of the given VMSS.

_Signature:_

```
VM ref set get_VMs (session ref session_ref, VMSS ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

### RPC name: remove&#95;from&#95;schedule

_Overview:_

_Signature:_

```
void remove_from_schedule (session ref session_ref, VMSS ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The snapshot schedule                   |
|`string`                      |`key`                         |the key to remove                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;enabled

_Overview:_

Set the enabled field of the given VMSS.

_Signature:_

```
void set_enabled (session ref session_ref, VMSS ref self, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |
|`bool`                        |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;frequency

_Overview:_

Set the value of the frequency field

_Signature:_

```
void set_frequency (session ref session_ref, VMSS ref self, vmss_frequency value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The snapshot schedule                   |
|`vmss_frequency`              |`value`                       |the snapshot schedule frequency         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;last&#95;run&#95;time

_Overview:_

_Signature:_

```
void set_last_run_time (session ref session_ref, VMSS ref self, datetime value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The snapshot schedule                   |
|`datetime`                    |`value`                       |the value to set                        |

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given VMSS.

_Signature:_

```
void set_name_description (session ref session_ref, VMSS ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given VMSS.

_Signature:_

```
void set_name_label (session ref session_ref, VMSS ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;retained&#95;snapshots

_Overview:_

_Signature:_

```
void set_retained_snapshots (session ref session_ref, VMSS ref self, int value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The schedule snapshot                   |
|`int`                         |`value`                       |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;schedule

_Overview:_

_Signature:_

```
void set_schedule (session ref session_ref, VMSS ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The snapshot schedule                   |
|`(string -> string) map`      |`value`                       |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;type

_Overview:_

_Signature:_

```
void set_type (session ref session_ref, VMSS ref self, vmss_type value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`self`                        |The snapshot schedule                   |
|`vmss_type`                   |`value`                       |the snapshot schedule type              |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: snapshot&#95;now

_Overview:_

This call executes the snapshot schedule immediately

_Signature:_

```
string snapshot_now (session ref session_ref, VMSS ref vmss)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VMSS ref`                    |`vmss`                        |Snapshot Schedule to execute            |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XMLRPC result
